;(function ( $, window, document, undefined ) {
	"use strict";

		var pluginName = "relativeFade";
		var defaults = {
				initialOpacity: 0.2,
				sensitivity: 50
		};

		function Plugin ( element, options ) {
				this.element = element;
				this.settings = $.extend( {}, defaults, options );
				this._defaults = defaults;
				this._name = pluginName;

				this.init();
		}

		$.extend(Plugin.prototype, {
				init: function () {
					this.$element = $(this.element);

					this.setDefaultOpacity(this.$element, this.settings);
					this.startListeners();
				},

				setDefaultOpacity: function(element, settings) {
					this.$element.css("opacity", settings.initialOpacity);
				},

				startListeners: function() {
					$(document).on("mousemove", this.updateElementOpacity.bind(this));
				},

				updateElementOpacity: function (event) {
					var pageX = event.pageX;
					var pageY = event.pageY;
					var elementOffset = this.$element.offset();
					var elementWidth = this.$element.width();
					var elementHeight = this.$element.height();
					var elementCenterX = elementOffset.left + (elementWidth / 2);
					var elementCenterY = elementOffset.top + (elementHeight / 2);
					var distX = Math.abs(pageX - elementCenterX);
					var distY = Math.abs(pageY - elementCenterY);
					var dist = Math.round(Math.sqrt(Math.pow(distX, 2) + Math.pow(distY, 2)));
					var opacity = 1 / (dist / this.settings.sensitivity);

					if (opacity >= this.settings.initialOpacity) {
						this.$element.css("opacity", opacity);
					}
				}
		});

		$.fn[ pluginName ] = function ( options ) {
				return this.each(function() {
						if ( !$.data( this, "plugin_" + pluginName ) ) {
								$.data( this, "plugin_" + pluginName, new Plugin( this, options ) );
						}
				});
		};

})( jQuery, window, document );
